@@ -110,7 +110,7 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #' used in the fitting process.
 #' @param weights an optional vector of weights to be used in the fitting
 #' process. Should be NULL or a numeric vector. If non-NULL, Bayes estimates
-#' are obtained assuming that Y ~ N(Xb, sigma^2 diag(1/weights)).
+#' are obtained assuming that \eqn{Y_i \sim N(x^T_i\beta, \sigma^2/w_i)}.
 #' @param contrasts an optional list. See the contrasts.arg of `model.matrix.default()`.
 #' @param na.action a function which indicates what should happen when the data
 #' contain NAs. The default is "na.omit".
@@ -162,8 +162,9 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #' Zellner's g-prior, alpha = g, for the Liang et al hyper-g or hyper-g-n
 #' method, recommended choice is alpha are between (2 < alpha < 4), with alpha
 #' = 3 the default.  For the Zellner-Siow prior alpha = 1 by default, but can be used
-#' to modify the rate parameter in the gamma prior on g,  1/g ~ G(1/2, n*alpha/2) so that
-#' beta ~ C(0, sigma^2 alpha (X'X/n)^{-1}).
+#' to modify the rate parameter in the gamma prior on g,  
+#' \deqn{1/g \sim G(1/2, n*\alpha/2)} so that
+#' \deqn{\beta \sim C(0, \sigma^2 \alpha (X'X/n)^{-1})}.
 #' @param modelprior A function for a family of prior distribution on the models.  Choices
 #' include \code{\link{uniform}} \code{\link{Bernoulli}} or
 #' \code{\link{beta.binomial}}, \code{\link{tr.beta.binomial}},
@@ -229,7 +230,7 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #' @param lambda Parameter in the AMCMC algorithm (deprecated).
 #' @param delta truncation parameter to prevent sampling probabilities to
 #' degenerate to 0 or 1 prior to enumeration for sampling without replacement.
-#' @param thin For "MCMC", thin the MCMC chain every "thin" iterations; default is no
+#' @param thin For "MCMC" or "MCMC+BAS", thin the MCMC chain every "thin" iterations; default is no
 #' thinning.  For large p, thinning can be used to significantly reduce memory
 #' requirements as models and associated summaries are saved only every thin iterations.  For thin = p, the  model and associated output are recorded every p iterations,
 #' similar to the Gibbs sampler in SSVS.
@@ -363,14 +364,17 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #'
 #' library(MASS)
 #' data(UScrime)
+#' 
+#' # pivot=FALSE is faster, but should only be used in full rank case
+#' # default is pivot = TRUE
 #' crime.bic <- bas.lm(log(y) ~ log(M) + So + log(Ed) +
 #'   log(Po1) + log(Po2) +
 #'   log(LF) + log(M.F) + log(Pop) + log(NW) +
 #'   log(U1) + log(U2) + log(GDP) + log(Ineq) +
 #'   log(Prob) + log(Time),
-#' data = UScrime, n.models = 2^15, prior = "BIC",
-#' modelprior = beta.binomial(1, 1),
-#' initprobs = "eplogp", pivot = FALSE
+#'   data = UScrime, n.models = 2^15, prior = "BIC",
+#'   modelprior = beta.binomial(1, 1),
+#'   initprobs = "eplogp", pivot = FALSE
 #' )
 #'
 #'
@@ -379,12 +383,12 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #'   log(Po1) + log(Po2) +
 #'   log(LF) + log(M.F) + log(Pop) + log(NW) +
 #'   log(U1) + log(U2) + log(GDP) + log(Ineq) +
-#'   log(Prob) + log(Time),
-#' data = UScrime,
-#' method = "MCMC",
-#' MCMC.iterations = 20000, prior = "BIC",
-#' modelprior = beta.binomial(1, 1),
-#' initprobs = "eplogp", pivot = FALSE
+#'  log(Prob) + log(Time),
+#'   data = UScrime,
+#'   method = "MCMC",
+#'   MCMC.iterations = 20000, prior = "BIC",
+#'   modelprior = beta.binomial(1, 1),
+#'   initprobs = "eplogp", pivot = FALSE
 #' )
 #'
 #' summary(crime.bic)
@@ -403,6 +407,11 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #' summary(TG.bas)
 #' image(TG.bas)
 #'
+#' 
+#' # don't run the following due to time limits on CRAN 
+#' 
+#' \dontrun{
+#' 
 #' # exmple with non-full rank case
 #'
 #' loc <- system.file("testdata", package = "BAS")
@@ -410,10 +419,8 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #' fullModelFormula <- as.formula("contNormal ~  contGamma * contExpon +
 #'                                 contGamma * contcor1 + contExpon * contcor1")
 #'
-#' # don't run the following due to time limits on CRAN 
-#' 
-#' \dontrun{
-#' # will trigger a warning 
+#' # should trigger a warning (default is to use pivoting, so use pivot=FALSE 
+#' # only for full rank case)
 #' 
 #'  out = bas.lm(fullModelFormula,
 #'               data = d,
@@ -485,7 +492,7 @@ bas.lm <- function(formula,
     "JZS"
   )
 
-  if (!(prior %in% priormethods)) {
+  if (is.null(prior) | !(prior %in% priormethods)) {
     stop(paste(
       "prior ",
       prior,
@@ -652,10 +659,14 @@ bas.lm <- function(formula,
       NULL
     )
   }
-
+  
+  
+  # start  nocov
+  # shouldn't be able to get here
   if (is.null(alpha)) {
-    alpha <- 0.0
+    stop("Error in BAS code, please report on GitHub")
   }
+  # end nocov 
 
   parents <- matrix(1, 1, 1)
   if (method == "MCMC+BAS" |
@@ -675,12 +686,12 @@ bas.lm <- function(formula,
   prob <- normalize.initprobs.lm(initprobs, p)
 
   if (is.null(bestmodel)) {
-    #bestmodel = as.integer(initprobs)
     bestmodel = as.integer(prob)
-    #bestmodel <- c(1, rep(0, p - 1))
   }
 
   bestmodel[keep] <- 1
+  
+
 
   if (force.heredity) {
     update <- NULL # do not update tree  FIXME LATER
@@ -692,7 +703,7 @@ bas.lm <- function(formula,
   }
 
 
-
+  bestmodel = as.integer(bestmodel)
   n.models <- normalize.n.models(n.models, p, prob,
                                   method, bigmem)
   #  print(n.models)
@@ -759,7 +770,10 @@ bas.lm <- function(formula,
       as.integer(MCMC.iterations),
       as.numeric(lambda),
       as.numeric(delta),
-      Rparents = parents
+      Rthin = as.integer(thin),
+      Rparents = parents,
+      Rpivot = pivot,
+      Rtol = tol
     ),
     "MCMC" = .Call(
       C_mcmc_new,
@@ -779,7 +793,7 @@ bas.lm <- function(formula,
       as.integer(MCMC.iterations),
       as.numeric(lambda),
       as.numeric(delta),
-      as.integer(thin),
+      Rthin = as.integer(thin),
       Rparents = parents,
       Rpivot = pivot,
       Rtol = tol
