@@ -54,6 +54,17 @@ struct Node {
 
 
 /* Subroutines. */
+
+double CalculateRSquareFull(double *XtY, double *XtX, double *XtXwork, double *XtYwork,
+                            SEXP Rcoef_m, SEXP Rse_m, int p, int nobs, double yty, double SSY);
+int *GetModel_m(SEXP Rmodel_m, int *model, int p);
+void SetModel2(double logmargy, double shrinkage_m, double prior_m,
+               SEXP sampleprobs, SEXP logmarg, SEXP shrinkage, SEXP priorprobs, int m);
+void SetModel(SEXP Rcoef_m, SEXP Rse_m, SEXP Rmodel_m, double mse_m, double R2_m,
+              SEXP beta, SEXP se, SEXP modelspace, SEXP mse, SEXP R2, int m);
+void SetModel_lm(SEXP Rcoef_m, SEXP Rse_m, SEXP Rmodel_m, double mse_m, double R2_m,
+                 SEXP beta, SEXP se, SEXP modelspace, SEXP mse, SEXP R2, int m);
+
 double hyp2f1(double a, double b, double c, double x);
 void compute_margprobs(SEXP modelspace, SEXP modeldim, SEXP Rmodelprobs, double *margprobs, int k, int p);
 void compute_margprobs_file(SEXP modeldim, SEXP Rmodelprobs, double *margprobs, int k, int p, FILE *file, int *model);
@@ -244,13 +255,13 @@ typedef struct glmfamilystruc {
   void (*initialize)(double *Y, double *mu, double *weights, int n);
   double (*dispersion)(double *resid,  double *weights, int n, int rank);
   void (*info_matrix) (double *y, double *mu, double *weights, double *var, int n);
-  double (*loglik) (double *y, double *mu, double *weights, int n);
+  double (*loglik) (double *y, double *mu, double *weights, double devb, int n);
 } glmstptr;
 
 glmstptr * make_glmfamily_structure(SEXP family);
 
 // Binomial family
-double binomial_loglik(double *Y, double *mu, double *wts, int n);
+double binomial_loglik(double *Y, double *mu, double *wts, double devb, int n);
 void logit_link(double *mu, double *eta, int n);
 void logit_variance(double *mu, double *var, int n);
 void logit_linkinv(double *eta, double *mu, int n);
@@ -260,7 +271,7 @@ void binomial_dev_resids(double *y, double *mu, double *wt, double *res, int n);
 double binomial_dispersion(double *resid,  double *weights, int n, int rank);
 void binomial_initialize(double *Y, double *mu,  double *weights, int n);
 // Poisson
-double poisson_loglik(double *Y, double *mu, double *wts, int n);
+double poisson_loglik(double *Y, double *mu, double *wts, double devb, int n);
 double poisson_dispersion(double *resid,  double *weights, int n, int rank) ;
 void log_link(double *mu, double *eta, int n);
 void poisson_variance(double *mu, double *var, int n);
@@ -269,6 +280,11 @@ void log_mu_eta(double *eta, double *mu, int n);
 void poisson_log_info(double *y, double *mu, double *weights, double *var, int n);
 void poisson_dev_resids(double *y, double *mu, double *wt, double *res, int n);
 void poisson_initialize(double *Y, double *mu,  double *weights, int n);
+// Gamma
+double gamma_loglik(double *Y, double *mu, double *wts, double devb, int n);
+void gamma_variance(double *mu, double *var, int n);
+void gamma_dev_resids(double *y, double *mu, double *wt, double *res, int n);
+void gamma_initialize(double *Y, double *mu,  double *weights, int n);
 
 
 // Normal
@@ -310,14 +326,14 @@ void SetModel2(double logmargy, double shrinkage_m, double prior_m,
 double FitModel(SEXP Rcoef_m, SEXP Rse_m, double *XtY, double *XtX, int *model_m,
                 double *XtYwork, double *XtXwork, double yty, double SSY, int pmodel, int p,
                 int nobs, int m, double *pmse_m, int *rank_m, int pivot, double tol);
-SEXP glm_FitModel(SEXP RX, SEXP RY, SEXP Rmodel_m,  //input data
+SEXP glm_FitModel(SEXP RX, SEXP RY, SEXP Rmodel_m, //input data
                   SEXP Roffset, SEXP Rweights,
                   glmstptr * glmfamily, SEXP Rcontrol,
                   SEXP Rlaplace, betapriorptr * betapriorfamily);
 
 SEXP glm_bas(SEXP RX, SEXP RY, glmstptr * family, SEXP Roffset, SEXP Rweights, SEXP Rcontrol);
 
-SEXP gglm_lpy(SEXP RX, SEXP RY,SEXP Rcoef, SEXP Rmu, SEXP Rweights, glmstptr * glmfamily, betapriorptr * betapriorfamily, SEXP Rlaplace);
+SEXP gglm_lpy(SEXP RX, SEXP RY,SEXP Rcoef, SEXP Rmu, SEXP Rdeviance, SEXP Rweights, glmstptr * glmfamily, betapriorptr * betapriorfamily, SEXP Rlaplace);
 
 
 // issue 38
